==> zio-aws-chimesdkmeetings_2.13-5.17.217.1-sources.jar: zio/aws/chimesdkmeetings/model/Meeting.scala <==
package zio.aws.chimesdkmeetings.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmeetings.model.primitives.{
  MediaRegion,
  PrimaryMeetingId,
  GuidString,
  ExternalMeetingId,
  ExternalUserId
}
import scala.jdk.CollectionConverters._
final case class Meeting(
    meetingId: Optional[GuidString] = Optional.Absent,
    meetingHostId: Optional[ExternalUserId] = Optional.Absent,
    externalMeetingId: Optional[ExternalMeetingId] = Optional.Absent,
    mediaRegion: Optional[MediaRegion] = Optional.Absent,
    mediaPlacement: Optional[zio.aws.chimesdkmeetings.model.MediaPlacement] =
      Optional.Absent,
    meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration
    ] = Optional.Absent,
    primaryMeetingId: Optional[PrimaryMeetingId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmeetings.model.Meeting = {
    import Meeting.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
      .builder()
      .optionallyWith(
        meetingId.map(value => GuidString.unwrap(value): java.lang.String)
      )(_.meetingId)
      .optionallyWith(
        meetingHostId.map(value =>
          ExternalUserId.unwrap(value): java.lang.String
        )
      )(_.meetingHostId)
      .optionallyWith(
        externalMeetingId.map(value =>
          ExternalMeetingId.unwrap(value): java.lang.String
        )
      )(_.externalMeetingId)
      .optionallyWith(
        mediaRegion.map(value => MediaRegion.unwrap(value): java.lang.String)
      )(_.mediaRegion)
      .optionallyWith(mediaPlacement.map(value => value.buildAwsValue()))(
        _.mediaPlacement
      )
      .optionallyWith(meetingFeatures.map(value => value.buildAwsValue()))(
        _.meetingFeatures
      )
      .optionallyWith(
        primaryMeetingId.map(value =>
          PrimaryMeetingId.unwrap(value): java.lang.String
        )
      )(_.primaryMeetingId)
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmeetings.model.Meeting.ReadOnly =
    zio.aws.chimesdkmeetings.model.Meeting.wrap(buildAwsValue())
}
object Meeting {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmeetings.model.Meeting =
      zio.aws.chimesdkmeetings.model.Meeting(
        meetingId.map(value => value),
        meetingHostId.map(value => value),
        externalMeetingId.map(value => value),
        mediaRegion.map(value => value),
        mediaPlacement.map(value => value.asEditable),
        meetingFeatures.map(value => value.asEditable),
        primaryMeetingId.map(value => value)
      )
    def meetingId: Optional[GuidString]
    def meetingHostId: Optional[ExternalUserId]
    def externalMeetingId: Optional[ExternalMeetingId]
    def mediaRegion: Optional[MediaRegion]
    def mediaPlacement
        : Optional[zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly]
    def meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ]
    def primaryMeetingId: Optional[PrimaryMeetingId]
    def getMeetingId: ZIO[Any, AwsError, GuidString] =
      AwsError.unwrapOptionField("meetingId", meetingId)
    def getMeetingHostId: ZIO[Any, AwsError, ExternalUserId] =
      AwsError.unwrapOptionField("meetingHostId", meetingHostId)
    def getExternalMeetingId: ZIO[Any, AwsError, ExternalMeetingId] =
      AwsError.unwrapOptionField("externalMeetingId", externalMeetingId)
    def getMediaRegion: ZIO[Any, AwsError, MediaRegion] =
      AwsError.unwrapOptionField("mediaRegion", mediaRegion)
    def getMediaPlacement: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly
    ] = AwsError.unwrapOptionField("mediaPlacement", mediaPlacement)
    def getMeetingFeatures: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("meetingFeatures", meetingFeatures)
    def getPrimaryMeetingId: ZIO[Any, AwsError, PrimaryMeetingId] =
      AwsError.unwrapOptionField("primaryMeetingId", primaryMeetingId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ) extends zio.aws.chimesdkmeetings.model.Meeting.ReadOnly {
    override val meetingId: Optional[GuidString] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingId())
      .map(value => zio.aws.chimesdkmeetings.model.primitives.GuidString(value))
    override val meetingHostId: Optional[ExternalUserId] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingHostId())
      .map(value =>
        zio.aws.chimesdkmeetings.model.primitives.ExternalUserId(value)
      )
    override val externalMeetingId: Optional[ExternalMeetingId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.externalMeetingId())
        .map(value =>
          zio.aws.chimesdkmeetings.model.primitives.ExternalMeetingId(value)
        )
    override val mediaRegion: Optional[MediaRegion] = zio.aws.core.internal
      .optionalFromNullable(impl.mediaRegion())
      .map(value =>
        zio.aws.chimesdkmeetings.model.primitives.MediaRegion(value)
      )
    override val mediaPlacement
        : Optional[zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mediaPlacement())
        .map(value => zio.aws.chimesdkmeetings.model.MediaPlacement.wrap(value))
    override val meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingFeatures())
      .map(value =>
        zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.wrap(value)
      )
    override val primaryMeetingId: Optional[PrimaryMeetingId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.primaryMeetingId())
        .map(value =>
          zio.aws.chimesdkmeetings.model.primitives.PrimaryMeetingId(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ): zio.aws.chimesdkmeetings.model.Meeting.ReadOnly = new Wrapper(impl)
}

==> zio-aws-chimesdkmeetings_2.13-7.21.15.5-sources.jar: zio/aws/chimesdkmeetings/model/Meeting.scala <==
package zio.aws.chimesdkmeetings.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmeetings.model.primitives.{
  MediaRegion,
  PrimaryMeetingId,
  GuidString,
  ExternalMeetingId,
  AmazonResourceName,
  ExternalUserId,
  TenantId
}
import scala.jdk.CollectionConverters._
final case class Meeting(
    meetingId: Optional[GuidString] = Optional.Absent,
    meetingHostId: Optional[ExternalUserId] = Optional.Absent,
    externalMeetingId: Optional[ExternalMeetingId] = Optional.Absent,
    mediaRegion: Optional[MediaRegion] = Optional.Absent,
    mediaPlacement: Optional[zio.aws.chimesdkmeetings.model.MediaPlacement] =
      Optional.Absent,
    meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration
    ] = Optional.Absent,
    primaryMeetingId: Optional[PrimaryMeetingId] = Optional.Absent,
    tenantIds: Optional[Iterable[TenantId]] = Optional.Absent,
    meetingArn: Optional[AmazonResourceName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmeetings.model.Meeting = {
    import Meeting.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
      .builder()
      .optionallyWith(
        meetingId.map(value => GuidString.unwrap(value): java.lang.String)
      )(_.meetingId)
      .optionallyWith(
        meetingHostId.map(value =>
          ExternalUserId.unwrap(value): java.lang.String
        )
      )(_.meetingHostId)
      .optionallyWith(
        externalMeetingId.map(value =>
          ExternalMeetingId.unwrap(value): java.lang.String
        )
      )(_.externalMeetingId)
      .optionallyWith(
        mediaRegion.map(value => MediaRegion.unwrap(value): java.lang.String)
      )(_.mediaRegion)
      .optionallyWith(mediaPlacement.map(value => value.buildAwsValue()))(
        _.mediaPlacement
      )
      .optionallyWith(meetingFeatures.map(value => value.buildAwsValue()))(
        _.meetingFeatures
      )
      .optionallyWith(
        primaryMeetingId.map(value =>
          PrimaryMeetingId.unwrap(value): java.lang.String
        )
      )(_.primaryMeetingId)
      .optionallyWith(
        tenantIds.map(value =>
          value.map { item =>
            TenantId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.tenantIds)
      .optionallyWith(
        meetingArn.map(value =>
          AmazonResourceName.unwrap(value): java.lang.String
        )
      )(_.meetingArn)
      .build()
  }
  def asReadOnly: zio.aws.chimesdkmeetings.model.Meeting.ReadOnly =
    zio.aws.chimesdkmeetings.model.Meeting.wrap(buildAwsValue())
}
object Meeting {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmeetings.model.Meeting =
      zio.aws.chimesdkmeetings.model.Meeting(
        meetingId.map(value => value),
        meetingHostId.map(value => value),
        externalMeetingId.map(value => value),
        mediaRegion.map(value => value),
        mediaPlacement.map(value => value.asEditable),
        meetingFeatures.map(value => value.asEditable),
        primaryMeetingId.map(value => value),
        tenantIds.map(value => value),
        meetingArn.map(value => value)
      )
    def meetingId: Optional[GuidString]
    def meetingHostId: Optional[ExternalUserId]
    def externalMeetingId: Optional[ExternalMeetingId]
    def mediaRegion: Optional[MediaRegion]
    def mediaPlacement
        : Optional[zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly]
    def meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ]
    def primaryMeetingId: Optional[PrimaryMeetingId]
    def tenantIds: Optional[List[TenantId]]
    def meetingArn: Optional[AmazonResourceName]
    def getMeetingId: ZIO[Any, AwsError, GuidString] =
      AwsError.unwrapOptionField("meetingId", meetingId)
    def getMeetingHostId: ZIO[Any, AwsError, ExternalUserId] =
      AwsError.unwrapOptionField("meetingHostId", meetingHostId)
    def getExternalMeetingId: ZIO[Any, AwsError, ExternalMeetingId] =
      AwsError.unwrapOptionField("externalMeetingId", externalMeetingId)
    def getMediaRegion: ZIO[Any, AwsError, MediaRegion] =
      AwsError.unwrapOptionField("mediaRegion", mediaRegion)
    def getMediaPlacement: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly
    ] = AwsError.unwrapOptionField("mediaPlacement", mediaPlacement)
    def getMeetingFeatures: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("meetingFeatures", meetingFeatures)
    def getPrimaryMeetingId: ZIO[Any, AwsError, PrimaryMeetingId] =
      AwsError.unwrapOptionField("primaryMeetingId", primaryMeetingId)
    def getTenantIds: ZIO[Any, AwsError, List[TenantId]] =
      AwsError.unwrapOptionField("tenantIds", tenantIds)
    def getMeetingArn: ZIO[Any, AwsError, AmazonResourceName] =
      AwsError.unwrapOptionField("meetingArn", meetingArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ) extends zio.aws.chimesdkmeetings.model.Meeting.ReadOnly {
    override val meetingId: Optional[GuidString] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingId())
      .map(value => zio.aws.chimesdkmeetings.model.primitives.GuidString(value))
    override val meetingHostId: Optional[ExternalUserId] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingHostId())
      .map(value =>
        zio.aws.chimesdkmeetings.model.primitives.ExternalUserId(value)
      )
    override val externalMeetingId: Optional[ExternalMeetingId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.externalMeetingId())
        .map(value =>
          zio.aws.chimesdkmeetings.model.primitives.ExternalMeetingId(value)
        )
    override val mediaRegion: Optional[MediaRegion] = zio.aws.core.internal
      .optionalFromNullable(impl.mediaRegion())
      .map(value =>
        zio.aws.chimesdkmeetings.model.primitives.MediaRegion(value)
      )
    override val mediaPlacement
        : Optional[zio.aws.chimesdkmeetings.model.MediaPlacement.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mediaPlacement())
        .map(value => zio.aws.chimesdkmeetings.model.MediaPlacement.wrap(value))
    override val meetingFeatures: Optional[
      zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.meetingFeatures())
      .map(value =>
        zio.aws.chimesdkmeetings.model.MeetingFeaturesConfiguration.wrap(value)
      )
    override val primaryMeetingId: Optional[PrimaryMeetingId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.primaryMeetingId())
        .map(value =>
          zio.aws.chimesdkmeetings.model.primitives.PrimaryMeetingId(value)
        )
    override val tenantIds: Optional[List[TenantId]] = zio.aws.core.internal
      .optionalFromNullable(impl.tenantIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmeetings.model.primitives.TenantId(item)
        }.toList
      )
    override val meetingArn: Optional[AmazonResourceName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.meetingArn())
        .map(value =>
          zio.aws.chimesdkmeetings.model.primitives.AmazonResourceName(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmeetings.model.Meeting
  ): zio.aws.chimesdkmeetings.model.Meeting.ReadOnly = new Wrapper(impl)
}
